@@ -30,8 +30,7 @@ def save_omas_nc(ods, filename, **kw):
             dims = []
             data = numpy.asarray(odsf[item])
             std = None
-            tmp = is_uncertain(odsf[item])
-            if numpy.any(numpy.atleast_1d(tmp)):
+            if is_uncertain(odsf[item]):
                 std = std_devs(data)
                 data = nominal_values(data)
             for k in range(len(numpy.asarray(odsf[item]).shape)):
@@ -100,7 +99,6 @@ def load_omas_nc(filename, consistency_check=True, imas_version=omas_rcparams['d
             if item.endswith('_error_upper'):
                 continue
             ods.setraw(p2l(item), get_ds_item(dataset, item))
-    ods.set_child_locations()
     ods.consistency_check = consistency_check
     return ods
 
@@ -108,8 +106,7 @@ def load_omas_nc(filename, consistency_check=True, imas_version=omas_rcparams['d
 class dynamic_omas_nc(dynamic_ODS):
     """
     Class that provides dynamic data loading from NC file
-    This class is not to be used by itself, but via the
-    ODS.open() method.
+    This class is not to be used by itself, but via the ODS.open() method.
     """
 
     def __init__(self, filename):
@@ -158,6 +155,7 @@ def through_omas_nc(ods, method=['function', 'class_method'][1]):
     :return: ods
     """
     filename = omas_testdir(__file__) + '/test.nc'
+    ods = copy.deepcopy(ods)  # make a copy to make sure save does not alter entering ODS
     if method == 'function':
         save_omas_json(ods, filename)
         ods1 = load_omas_json(filename)
